16.26. cdist-type__consul_watch_checks(7) — cdist 6.1.1 documentation

# 16.26. cdist-type__consul_watch_checks(7)

## 16.26.1. NAME

cdist-type__consul_watch_checks - Manages consul checks watches

## 16.26.2. DESCRIPTION

Generate and deploy watch definitions of type 'checks' for a consul agent. See http://www.consul.io/docs/agent/watches.html for parameter documentation.

## 16.26.3. REQUIRED PARAMETERS

handler
  the handler to invoke when the data view updates

## 16.26.4. OPTIONAL PARAMETERS

datacenter
  can be provided to override the agent's default datacenter
filter-service
  filter to a specific service. Conflicts with --filter-state.
filter-state
  filter to a specific state. Conflicts with --filter-service.
state
  if this watch is 'present' or 'absent'. Defaults to 'present'.
token
  can be provided to override the agent's default ACL token

## 16.26.5. EXAMPLES

    __consul_watch_checks some-id \
       --handler /usr/bin/my-handler.sh

    __consul_watch_checks some-id \
       --filter-service consul \
       --handler /usr/bin/my-handler.sh

    __consul_watch_checks some-id \
       --filter-state passing \
       --handler /usr/bin/my-handler.sh

## 16.26.6. SEE ALSO

cdist-type__consul_agent(7)

consul documentation at: <http://www.consul.io/docs/agent/watches.html>.

## 16.26.7. AUTHORS

Steven Armstrong <steven-cdist--@--armstrong.cc>

## 16.26.8. COPYING

Copyright (C) 2015 Steven Armstrong. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.